==> jc-1.4.0.tar.gz: gnu/xml/transform/AttributeSet.h <==
// final class gnu.xml.transform.AttributeSet

// class file dependencies
// @dep_class 60a08c7ac570a92a gnu_xml_transform_AttributeSet
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_AttributeSet_H_
#define _JC_gnu_xml_transform_AttributeSet_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_AttributeSet$object;
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_AttributeSet$sub_refs	_jc_gnu_xml_transform_AttributeSet$sub_refs;
typedef struct _jc_gnu_xml_transform_AttributeSet$sub_nonrefs	_jc_gnu_xml_transform_AttributeSet$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_AttributeSet$refs	_jc_gnu_xml_transform_AttributeSet$refs;
typedef struct _jc_gnu_xml_transform_AttributeSet$nonrefs	_jc_gnu_xml_transform_AttributeSet$nonrefs;
typedef struct _jc_gnu_xml_transform_AttributeSet$object	_jc_gnu_xml_transform_AttributeSet$object;

typedef const struct _jc_gnu_xml_transform_AttributeSet$vmethods	_jc_gnu_xml_transform_AttributeSet$vmethods;
typedef const struct _jc_gnu_xml_transform_AttributeSet$vtable	_jc_gnu_xml_transform_AttributeSet$vtable;
typedef const struct _jc_gnu_xml_transform_AttributeSet$vtype	_jc_gnu_xml_transform_AttributeSet$vtype;

// Constructors
extern void _jc_gnu_xml_transform_AttributeSet$method$_init$737e1cf96a1d352c(_jc_env *, struct _jc_gnu_xml_transform_AttributeSet$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_gnu_xml_transform_AttributeSet$object *_jc_gnu_xml_transform_AttributeSet$method$clone$bffc35b9041a70d9(_jc_env *, struct _jc_gnu_xml_transform_AttributeSet$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_AttributeSet$method_info$clone$bffc35b9041a70d9;

// Virtual methods structure
struct _jc_gnu_xml_transform_AttributeSet$vmethods {
	struct _jc_gnu_xml_transform_AttributeSet$object	*(*clone$bffc35b9041a70d9)(_jc_env *, struct _jc_gnu_xml_transform_AttributeSet$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
};

// Vtable
struct _jc_gnu_xml_transform_AttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_AttributeSet$vmethods	gnu_xml_transform_AttributeSet;
};

// Vtype
struct _jc_gnu_xml_transform_AttributeSet$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_AttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_AttributeSet$sub_refs {
	struct _jc_gnu_xml_transform_TemplateNode$object	*children;
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*uas;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_AttributeSet$refs {
    _jc_gnu_xml_transform_AttributeSet$sub_refs	gnu_xml_transform_AttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_AttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_AttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_AttributeSet$sub_nonrefs	gnu_xml_transform_AttributeSet;
};

// Object instance structure
struct _jc_gnu_xml_transform_AttributeSet$object {
	_jc_gnu_xml_transform_AttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_AttributeSet$vtype	*vtype;
	_jc_gnu_xml_transform_AttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_AttributeSet$vtype _jc_gnu_xml_transform_AttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_AttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_AttributeSet$class_object;

#endif	/* _JC_gnu_xml_transform_AttributeSet_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/transform/AttributeSet.h <==
// final class gnu.xml.transform.AttributeSet

// class file dependencies
// @dep_class 60a08c7ac570a92a gnu_xml_transform_AttributeSet
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_AttributeSet_H_
#define _JC_gnu_xml_transform_AttributeSet_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_AttributeSet$object;
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_transform_TemplateNode$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_AttributeSet$sub_refs	_jc_gnu_xml_transform_AttributeSet$sub_refs;
typedef struct _jc_gnu_xml_transform_AttributeSet$sub_nonrefs	_jc_gnu_xml_transform_AttributeSet$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_AttributeSet$refs	_jc_gnu_xml_transform_AttributeSet$refs;
typedef struct _jc_gnu_xml_transform_AttributeSet$nonrefs	_jc_gnu_xml_transform_AttributeSet$nonrefs;
typedef struct _jc_gnu_xml_transform_AttributeSet$object	_jc_gnu_xml_transform_AttributeSet$object;

typedef const struct _jc_gnu_xml_transform_AttributeSet$vmethods	_jc_gnu_xml_transform_AttributeSet$vmethods;
typedef const struct _jc_gnu_xml_transform_AttributeSet$vtable	_jc_gnu_xml_transform_AttributeSet$vtable;
typedef const struct _jc_gnu_xml_transform_AttributeSet$vtype	_jc_gnu_xml_transform_AttributeSet$vtype;

// Constructors
extern void _jc_gnu_xml_transform_AttributeSet$method$_init$737e1cf96a1d352c(_jc_env *, struct _jc_gnu_xml_transform_AttributeSet$object *, struct _jc_gnu_xml_transform_TemplateNode$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_transform_AttributeSet$object *_jc_gnu_xml_transform_AttributeSet$method$clone$bffc35b9041a70d9(_jc_env *, struct _jc_gnu_xml_transform_AttributeSet$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_AttributeSet$method_info$clone$bffc35b9041a70d9;

// Virtual methods structure
struct _jc_gnu_xml_transform_AttributeSet$vmethods {
	struct _jc_gnu_xml_transform_AttributeSet$object	*(*clone$bffc35b9041a70d9)(_jc_env *, struct _jc_gnu_xml_transform_AttributeSet$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_AttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_AttributeSet$vmethods	gnu_xml_transform_AttributeSet;
};

// Vtype
struct _jc_gnu_xml_transform_AttributeSet$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_AttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_AttributeSet$sub_refs {
	struct _jc_gnu_xml_transform_TemplateNode$object	*children;
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_lang_String$object	*uas;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_AttributeSet$refs {
    _jc_gnu_xml_transform_AttributeSet$sub_refs	gnu_xml_transform_AttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_AttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_AttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_AttributeSet$sub_nonrefs	gnu_xml_transform_AttributeSet;
};

// Object instance structure
struct _jc_gnu_xml_transform_AttributeSet$object {
	_jc_gnu_xml_transform_AttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_AttributeSet$vtype	*vtype;
	_jc_gnu_xml_transform_AttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_AttributeSet$vtype _jc_gnu_xml_transform_AttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_AttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_AttributeSet$class_object;

#endif	/* _JC_gnu_xml_transform_AttributeSet_H_ */
